==> moodle-1.5-mysql.tgz: moodle/lang/th/dialogue.php <==
<?PHP // $Id$ 
      // dialogue.php - created with Moodle 1.6 development (2005052400)


$string['addmynewentries'] = 'ͤ';
$string['addmynewentry'] = 'ͤ';
$string['addsubject'] = 'Ǣ';
$string['allowmultiple'] = 'ٴ¡Ѻؤǡѹҡ˹觤';
$string['allowstudentdialogues'] = '͹حҵѡ¹¡ѹ';
$string['close'] = 'Դ';
$string['closed'] = 'Դ';
$string['confirmclosure'] = 'سѧлԴʹҡѺ $a ʹͻԴö¡ѹ سöд١ʹҷҹöʹŧ سͧʹҡͧä¡ѹ  \"㨹ФҵͧûԴʹҹ\" ';
$string['deleteafter'] = 'źʹѧҡ (ӹǹѹ)';
$string['dialogueclosed'] = 'ʹһԴ';
$string['dialogueintro'] = '鹺ʹ';
$string['dialoguemail'] = '$a->userfrom ʵͤѺʹ  \'$a->dialogue\'

سöҹ¡ԡʹҴѧ:

$a->url';
$string['dialoguemailhtml'] = '$a->userfrom ʵͤѺʹ \'<i>$a->dialogue</i>\'<br /><br />
سöҹ¡ԡ <a href=\"$a->url\">dialogue</a>.';
$string['dialoguename'] = 'ͺʹ';
$string['dialogueopened'] = 'ʹҡѺ$a';
$string['dialoguewith'] = 'ʹҡѺ$a';
$string['everybody'] = 'ء';
$string['furtherinformation'] = '';
$string['lastentry'] = 'ͤ';
$string['maildefault'] = '駤';
$string['mailnotification'] = '駷ҧ';
$string['modulename'] = 'ʹ';
$string['modulenameplural'] = 'ʹ';
$string['namehascloseddialogue'] = '$a Դʹ';
$string['newdialogueentries'] = 'ͤѺʹ';
$string['newentry'] = 'ͤ';
$string['noavailablepeople'] = 'ҧʹҴ';
$string['nopersonchosen'] = 'ռ١͡';
$string['nosubject'] = 'Ǣ';
$string['notextentered'] = 'ͤ';
$string['notstarted'] = 'سѧʹ';
$string['notyetseen'] = 'ѧ';
$string['numberofentries'] = 'ӹǹͤ';
$string['numberofentriesadded'] = 'ӹǹͤ $a  ͤ';
$string['of'] = 'ҡ';
$string['onwrote'] = '  $a  ¹';
$string['onyouwrote'] = ' $a  س¹';
$string['open'] = 'Դ';
$string['openadialoguewith'] = 'ԴʹҡѺ';
$string['opendialogue'] = 'Դʹ';
$string['opendialogueentries'] = 'ͤԴʹ';
$string['pane0'] = 'Դʹ';
$string['pane1'] = '$a  ʹ  ͡õͺҡس';
$string['pane1one'] = '˹觺ʹҷͤسͺ';
$string['pane2'] = '$a ʹҷ͡õͺҡ';
$string['pane2one'] = '˹觺ʹͺõͺҡ';
$string['pane3'] = '$a ʹҷԴ';
$string['pane3one'] = '˹觺ʹҷԴ';
$string['seen'] = '  $a  ';
$string['sendmailmessages'] = 'բͤҶ֧';
$string['status'] = 'ʶҹ';
$string['studenttostudent'] = 'ѡ¹Ѻѡ¹';
$string['subject'] = 'Ǣ';
$string['subjectadded'] = 'Ǣͷ';
$string['teachertostudent'] = '١Ѻѡ¹';
$string['typefirstentry'] = 'ͤá';
$string['typefollowup'] = 'ͤ价';
$string['typeofdialogue'] = 'ͧʹ';
$string['typereply'] = 'ͺ';
$string['viewallentries'] = ' $a ʹҷ';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/th/dialogue.php <==
<?PHP // $Id$ 
      // dialogue.php - created with Moodle 1.4.5 + (2004083150)


$string['addmynewentries'] = 'ͤ';
$string['addmynewentry'] = 'ͤ';
$string['addsubject'] = 'Ǣ';
$string['allowmultiple'] = 'ٴ¡Ѻؤǡѹҡ˹觤';
$string['allowstudentdialogues'] = '͹حҵѡ¹¡ѹ';
$string['close'] = 'Դ';
$string['closed'] = 'Դ';
$string['confirmclosure'] = 'سѧлԴʹҡѺ $a ʹͻԴö¡ѹ سöд١ʹҷҹöʹŧ سͧʹҡͧä¡ѹ  \"㨹ФҵͧûԴʹҹ\" ';
$string['deleteafter'] = 'źʹѧҡ (ӹǹѹ)';
$string['dialogueclosed'] = 'ʹһԴ';
$string['dialogueintro'] = '鹺ʹ';
$string['dialoguemail'] = '$a->userfrom ʵͤѺʹ  \'$a->dialogue\'

سöҹ¡ԡʹҴѧ:

$a->url';
$string['dialoguemailhtml'] = '$a->userfrom ʵͤѺʹ \'<i>$a->dialogue</i>\'<br /><br />
سöҹ¡ԡ <a href=\"$a->url\">dialogue</a>.';
$string['dialoguename'] = 'ͺʹ';
$string['dialogueopened'] = 'ʹҡѺ$a';
$string['dialoguewith'] = 'ʹҡѺ$a';
$string['everybody'] = 'ء';
$string['furtherinformation'] = '';
$string['lastentry'] = 'ͤ';
$string['maildefault'] = '駷ҧ';
$string['mailnotification'] = '駷ҧ';
$string['modulename'] = 'ʹ';
$string['modulenameplural'] = 'ʹ';
$string['namehascloseddialogue'] = '$a Դʹ';
$string['newdialogueentries'] = 'ͤѺʹ';
$string['newentry'] = 'ͤ';
$string['noavailablepeople'] = 'ҧʹҴ';
$string['nopersonchosen'] = 'ռ١͡';
$string['nosubject'] = 'Ǣ';
$string['notextentered'] = 'ͤ';
$string['notstarted'] = 'سѧʹ';
$string['notyetseen'] = 'ѧ';
$string['numberofentries'] = 'ӹǹͤ';
$string['numberofentriesadded'] = 'ӹǹͤ $a  ͤ';
$string['of'] = 'ҡ';
$string['onwrote'] = '  $a  ¹';
$string['onyouwrote'] = ' $a  س¹';
$string['open'] = 'Դ';
$string['openadialoguewith'] = 'ԴʹҡѺ';
$string['opendialogue'] = 'Դʹ';
$string['opendialogueentries'] = 'ͤԴʹ';
$string['pane0'] = 'Դ<br>ʹ';
$string['pane1'] = '$a  ʹ <br>ͤسͺ';
$string['pane1one'] = ' 1 ʹ<br>ͤسͺ';
$string['pane2'] = '$a ʹ<br>͡õͺѺ';
$string['pane2one'] = ' 1 ʹ<br>͡õͺѺ';
$string['pane3'] = '$a ʹ<br>Դ';
$string['pane3one'] = ' 1 ʹ<br>Դ';
$string['seen'] = '  $a  ';
$string['sendmailmessages'] = 'բͤҶ֧';
$string['status'] = 'ʶҹ';
$string['studenttostudent'] = 'ѡ¹Ѻѡ¹';
$string['subject'] = 'Ǣ';
$string['subjectadded'] = 'Ǣͷ';
$string['teachertostudent'] = 'ҨѺѡ¹';
$string['typefirstentry'] = 'ͤá';
$string['typefollowup'] = 'ͤ价';
$string['typeofdialogue'] = 'ͧʹ';
$string['typereply'] = 'ͺ';
$string['viewallentries'] = ' $a ʹҷ';

?>
